// Script para trazar el diagrama de Moody
// Primero definimos la función para Coolebrook-White
deff('[P]=CW(f)','P=1/sqrt(f)+0.8686*log(e/(3.7*D)+2.51/(Re*sqrt(f)))')
D = 0.025; //Diámetro del tubo: 2.5 cm, aprox. 1.0 inch
//Los siguientes dos vectores contienen los valores de la rugosidad y del
//número de Reynolds
e_v = [0.01 0.001 0.0001 0.00001 0.000001 0.0000001];
Re_v = [1e4 1e5 1e6 1e7 1e8];
[ne me] = size(e_v); //tamaño de los vectores
[nR mR] = size(Re_v); //e_v y Re_v
fMoody = zeros(mR,me); //Crea una matriz para valores de f
//Calcula los factores de fricción para combinaciones de valores
//de e_v(i) y de Re_v(j):
for j = 1:me
for i = 1:mR
Re = Re_v(i); e = D*e_v(j);
if e < 1e-5 then
f0 = 0.01;
else
f0 = 0.02;
end;
fMoody(i,j) = fsolve(f0,CW);
end;
end;
//Gráfica del Diagrama de Moody
plot2d('ll',Re_v',[fMoody(:,1),fMoody(:,2),...
fMoody(:,3),fMoody(:,4), fMoody(:,5), fMoody(:,6)],...
[1:6],leg='e=0.01@e=0.001@e=0.0001@e=0.00001@e=0.000001@e=0.0000001');
xlabel('Reynolds number')
ylabel('friction factor' )
title('Moody diagram')
set(gca(),"grid",[1 1])

//fin del script
